embassy-stm32

Crates

git

Versions

stm32h757xi-cm7

Flavors

DsiHost

Struct DsiHost 

pub struct DsiHost<'d, T: Instance> { /* private fields */ }
DSIHOST driver.

Implementations

Source

impl<'d, T: Instance> DsiHost<'d, T>

pub async fn enable_pll(&mut self, config: &DsiHostPllConfig)

Enable the DSIHOST PLL

Source

impl<'d, T: Instance> DsiHost<'d, T>

pub fn phy_init(&mut self, config: &DsiHostPhyConfig)

Initialize DSI D-PHY

Source

impl<'d, T: Instance> DsiHost<'d, T>

pub fn set_mode<Panel: DsiPanel>( &mut self, mode: &DsiHostMode, ) -> Result<(), Error>

Set the DSI mode

pub fn ltdc_refresh(&self)

Manual refresh of a frame from LTDC

pub fn enable_pattern_generator(&mut self, enable: bool)

Eneable video mode pattern generator. The DSI host must be initialized in video more before enabling the pattern generator

pub fn debug_registers()

Debug dump registers to defmt

Source

impl<'d, T: Instance> DsiHost<'d, T>

pub async fn init_panel<Panel: DsiPanel>( &mut self, color: DsiColor, ) -> Result<(), Error>

Initialize the panel using the generic type implementing DsiPanel

Source

impl<'d, T: Instance> DsiHost<'d, T>

pub fn new(_peri: Peri<'d, T>, te: Peri<'d, impl TePin<T>>) -> Self

Note: Full-Duplex modes are not supported at this time

pub async fn start_panel<Panel: DsiPanel>( &mut self, pll_config: &DsiHostPllConfig, phy_config: &DsiHostPhyConfig, mode: &DsiHostMode, ) -> Result<(), Error>

Start the DSI host

LTDC should be initialized before starting DSIHOST

  • Enable regulator
  • Initialize PLL and wait for lock
  • Initialize PHY
  • Initialize Mode
  • Initialize Panel
  • Enable DSI peripheral and DSI Wrapper
pub fn get_version(&self) -> u32

Get the DSIHOST hardware version. Found in the reference manual for comparison.

pub fn enable(&mut self)

Set the enable bit in the control register and assert that it has been enabled

pub fn disable(&mut self)

Unset the enable bit in the control register and assert that it has been disabled

pub fn enable_wrapper_dsi(&mut self)

Set the DSI enable bit in the wrapper control register and assert that it has been enabled

pub fn disable_wrapper_dsi(&mut self)

Unset the DSI enable bit in the wrapper control register and assert that it has been disabled

pub async fn enable_regulator(&mut self)

Enable the regulator

pub async fn wait_tear(&mut self)

Wait for a tear interrupt event

pub async fn wait_refresh(&mut self)

Wait for an end of refresh interrupt

pub fn write_cmd( &mut self, channel_id: u8, address: u8, data: &[u8], ) -> Result<(), Error>

DCS or Generic short/long write command

pub fn read( &mut self, channel_id: u8, packet_type: PacketType, read_size: u16, data: &mut [u8], ) -> Result<(), Error>

Read DSI Register