pub struct DsiHostPhyConfig {}Expand description
DSI PHY Configuration
Fields
lanes: DsiHostPhyLanesNumber of DSI PHY lanes
stop_wait_time: u8Stop wait time. Minimum wait period to request a high speed transmission after the stop state
tx_escape_div: u8TX escape clock div relative to lane byte clock
acr: boolD-PHY automatic clock lane control. Stops providing clock automatically.
crc_rx: boolEnable CRC RX enable
ecc_rx: boolEnable ECC RX enable
eotp_rx: boolEoTp RX enable
eotp_tx: boolEoTp TX enable
bta: boolBus Turnaround enable
clock_hs2lp: u16Clock high speed to low power timing
clock_lp2hs: u16Clock low power to high speed timing
data_hs2lp: u8Data high speed to low power timing
data_lp2hs: u8Data low power to high speed timing
data_mrd: u16Data maximum read time